﻿// =============================================================
// =============================================================

// Constant and variable declarations

// =============================================================


// (1) CONSTANTS ///////////////////////////////////////////////

var cERROR_PG = 'error.html';

var cCULTURE_EN = 'en-ca';
var cCULTURE_FR = 'fr-ca';

var userCulture;


// Location Array indices ..........

var cTITLE = 0;
var cLATLNG = 1;
var cADDRESS = 2;
var cCITY = 3;
var cPROV = 4;
var cPROVFULL = 5;
var cPOSTALCODE = 6;
var cWEBSITE = 7;
var cPHONE = 8;
var cISVISIBLE = 9;

// Language Array indices ..........

var cEN_CA = 0;
var cFR_CA = 1;


// (2) Labels ///////////////////////////////////////////////

// label used in the header of the results area
var lblResultPnlHdr = [
			"Listing of Accredited Organizations (as shown on map)",
			"Liste d'organismes agréés (qui figurent sur la carte)"
		];

// Header labels for dhtmlGrid
var lblSearchResultsHdr = [
			'Accredited Organization,LatLong,Address,City,Prov,Province,Postal Code,Website,Phone Number',
			'Organisme agrée,LatLong,Adresse,Ville,Prov,Province,Code Postale,Site web,Numéro de téléphone'
		];

// Legend Image Source
var imgLegend = [
			'img/legend_en.png',
			'img/legend_fr.png'
		];

// New Search Image Source
var imgNewSearch = [
			'img/newsearch_en.png',
			'img/newsearch_fr.png'
		];

// Link to Help Document
var helpDocSrc = [
			'help_en.htm',
			'help_fr.htm'
		];

// Label for Collapsed Results Panel
var listResultsLabel = [
            'List Results',
            'Résultats'
];


// (3) Page-Level Variable Declarations ///////////////////////////

var latlngSTARTPNT = new google.maps.LatLng(58.0, -98.7);

var map; 		// to be instance of Google map
var mc; 		// to be instance of MarkerClusterer

var grdOrgList;  // dhtmlx grid control

var locationData = [];  // full location array

var filteredLocationData = []; // array for filtered locations - will be bound to grdOrgList

var markers = []; // marker array for the GMap

var infos = []; // info array

var recCount; // record count (to display the number of records showing in grdOrgList

var infowindow = new google.maps.InfoWindow(); // Google Info Window


// =============================================================
// =============================================================

// Function declarations

// =============================================================

Element.prototype.getElementHeight = function() {

	if (typeof this.clip !== "undefined") {
    	return this.clip.height;
	} else {

    	if (this.style.pixelHeight) {
	        return this.style.pixelHeight;
    	} else {
	        return this.offsetHeight;
	    }
	}
};

window.onresize = function () {

    if (document.getElementById('map_canvas').getElementHeight() < 285) {
        map.setOptions({ zoomControlOptions: { style: google.maps.ZoomControlStyle.SMALL} });
    } else {
        map.setOptions({ zoomControlOptions: { style: google.maps.ZoomControlStyle.LARGE} });
    }

    grdOrgList.setSizes();

};


function initialize(culture) {

    try {

        //set language
        userCulture = culture;

        doInitGrid();

        var myOptions = {
            zoom: 3,
            center: latlngSTARTPNT,
            mapTypeId: google.maps.MapTypeId.ROADMAP,
            maxZoom: 20,
            zoomControlOptions: {
                style: google.maps.ZoomControlStyle.LARGE
            },
            panControl: false
        };

        map = new google.maps.Map(document.getElementById("map_canvas"),myOptions);

        map.setOptions({ zoomControlOptions: { style: google.maps.ZoomControlStyle.LARGE} });

        if (document.getElementById('map_canvas').getElementHeight() < 285) {
            map.setOptions({ zoomControlOptions: { style: google.maps.ZoomControlStyle.SMALL} });
        }

        //SetGridSize();

        if (culture == cCULTURE_FR) {
            document.getElementById("listResetBtn_en").style.visibility = 'hidden';
            document.getElementById("header").style.backgroundImage = "url(img/top_header_fr.png)";
            document.getElementById("mapLegend").style.backgroundImage = "url(img/legend_fr.png)";
        } else {
            document.getElementById("listResetBtn_fr").style.visibility = 'hidden';
            document.getElementById("header").style.backgroundImage = "url(img/top_header_en.png)";
            document.getElementById("mapLegend").style.backgroundImage = "url(img/legend_en.png)";
        }

        google.maps.event.addListener(map, 'idle', function () {
            FilterGridForVisibleMarkers();
        });

        google.maps.event.addListener(map, 'resize', function () {

            FilterGridForVisibleMarkers();

            var newOptions = {
                zoomControlOptions: {
                    style: google.maps.ZoomControlStyle.LARGE
                }
            }

            map.setOptions({ zoomControlOptions: { style: google.maps.ZoomControlStyle.LARGE} });

        });

        // =======================================================
        // add New Search Control to GMap....

        var newSearchCtrlDiv = document.createElement('DIV');
        var newSearchCtrl = new AddNewButton(newSearchCtrlDiv, map);

        newSearchCtrlDiv.index = 1;
        map.controls[google.maps.ControlPosition.BOTTOM_LEFT].push(newSearchCtrlDiv);

    }
    catch (er) {
        window.location = cERROR_PG
    }

}


// ==============================================================
// ==============================================================

function GenerateGeoPoint(Lat, Lng) {

    var mrkr = new google.maps.LatLng(Lat, Lng);
    return mrkr;

}

// ==============================================================
// ==============================================================

// This function takes an array argument containing a list of marker data
function generateMarkers(locations) {

    try {

        locationData = locations;
        filteredLocationData = locations;

        var image = new google.maps.MarkerImage(
					'img/image.png',
					new google.maps.Size(34, 31),
					new google.maps.Point(0, 0),
					new google.maps.Point(17, 31)
				);

        var shadow = new google.maps.MarkerImage(
					'img/shadow.png',
					new google.maps.Size(54, 31),
					new google.maps.Point(0, 0),
					new google.maps.Point(17, 31)
				);

        var shape = {
            coord: [19, 0, 20, 1, 27, 2, 28, 3, 28, 4, 28, 5, 28, 6, 27, 7, 27, 8, 31, 9, 32, 10, 33, 11, 33, 12, 32, 13, 31, 14, 33, 15, 33, 16, 33, 17, 33, 18, 33, 19, 24, 20, 24, 21, 24, 22, 24, 23, 23, 24, 18, 25, 18, 26, 18, 27, 18, 28, 19, 29, 19, 30, 15, 30, 15, 29, 15, 28, 15, 27, 15, 26, 15, 25, 10, 24, 9, 23, 9, 22, 10, 21, 10, 20, 1, 19, 0, 18, 0, 17, 0, 16, 1, 15, 3, 14, 2, 13, 1, 12, 1, 11, 2, 10, 3, 9, 7, 8, 7, 7, 7, 6, 6, 5, 6, 4, 6, 3, 7, 2, 8, 1, 16, 0, 19, 0],
            type: 'poly'
        };


        for (var i = 0; i < locations.length; i++) {

            var marker = new google.maps.Marker({
                position: locations[i][cLATLNG],
                map: map,
                title: locations[i][cTITLE],
                icon: image,
                shadow: shadow,
                shape: shape,
                draggable: false,
                raiseOnDrag: false
            });

            AttachMarkerInfo(marker, i);

            markers.push(marker);

        }

        var clusterStyles = [[{
            url: 'img/cluster4b.png',
            width: 29, height: 26,
            opt_anchor: [15, 15],
            textColor: '#ffffff',
            textSize: 12
        }]];

        // now instantiate marker clusterer....

        var mcOptions = {
            maxZoom: 11,
            gridSize: 40,
            styles: clusterStyles[0]
        };

        mc = new MarkerClusterer(map, markers, mcOptions);
    }
    catch (er) {
        window.location = cERROR_PG
    }


}

// ==============================================================
// ==============================================================

function doInitGrid() {

    try {

        grdOrgList = new dhtmlXGridObject('grdOrgList_container');

        grdOrgList.setImagePath("dhtmlxGridPro/codebase/imgs/");

        grdOrgList.enableDistributedParsing(true, 10, 50);
        grdOrgList.enableAutoHeight(false);
        grdOrgList.setSizes();

        grdOrgList.setHeader(getLabel(lblSearchResultsHdr));

        // setColumnsVisibility sets each columns visibility...
        // NOTE: false = visible, true = invisible ....
        grdOrgList.setColumnsVisibility("false,true,true,false,true,false,true,true,false");
        grdOrgList.setInitWidths("*,0,0,200,0,200,0,0,200");
        grdOrgList.setColAlign("left,left,left,left,center,left,left,left,left");

        grdOrgList.setSkin("dhx_skyblue");

        grdOrgList.enablePaging(false, 10, 3, "pagingArea", true, "recinfoArea");
        grdOrgList.attachHeader("#text_filter,,,#text_filter,,#select_filter,,,");

        grdOrgList.init();

        // now add event handler to highlight a map marker's
        // infoWindow if its equivalent record was selected
        // in the search results grid...

        grdOrgList.attachEvent("onRowSelect", function (id) {

            // get the title of the selected row...
            var title = filteredLocationData[id - 1][cTITLE];

            // then loop through the list of markers until we find
            var selectedMarkerIndex;

            for (var i = 0; i < markers.length; i++) {

                if (markers[i].title == title) {

                    selectedMarkerIndex = i;
                    break;

                }

            }
            // the LatLng that matches...
            FindMarker(selectedMarkerIndex);

        });
    }
    catch (er) {
        window.location = cERROR_PG
    }
}

// ==============================================================
// ==============================================================

function BindDataToGrid() {

    try {
        //alert('binding org data to grid....');

        grdOrgList.parse(filteredLocationData, "jsarray");

        // refresh filters...
        grdOrgList.refreshFilters();

        UpdateRecCount();

        grdOrgList.setSizes();
    }
    catch (er) {
        window.location = cERROR_PG
    }

}

// ==============================================================
// ==============================================================

function FilterGridForVisibleMarkers() {

    try {
        //alert('Filtering grid....');
        filteredLocationData = []; // reset the filteredLocationData Array

        for (var i = 0; i < markers.length; i++) {

            if (map.getBounds().contains(markers[i].getPosition())) {

                locationData[i][cISVISIBLE] = 1;
                filteredLocationData.push(locationData[i]);

            }
            else {

                locationData[i][cISVISIBLE] = 0;

            }

        }

        grdOrgList.clearAll();
        BindDataToGrid();

    }
    catch (er) {
        window.location = cERROR_PG
    }

}

// ==============================================================
// ==============================================================

function AttachMarkerInfo(marker, number) {

    try {

        var contentString = '<div id="content" class="infoWindow">' +
					'<div id="firstHeading" class="firstHeading">' + locationData[number][cTITLE] + '</div>' +
					'<div id="bodyContent" class="infoWindowDetails">' +
					locationData[number][cADDRESS] + '<br />' +
					locationData[number][cCITY] + ', ' +
					locationData[number][cPROV] + ', ' +
					locationData[number][cPOSTALCODE] + '<br /><div class="infoContact">';


        if (locationData[number][cPHONE].length > 3) {

            contentString += locationData[number][cPHONE];

        }

        if (locationData[number][cWEBSITE].length > 3) {

            contentString += '<br />' +
						'<a class="mapLink" target="_blank" href="http://' +
						locationData[number][cWEBSITE] + '">' +
						locationData[number][cWEBSITE] + '</a>';

        }


        contentString += '</div></div></div>';

//        var infoWindowOptions = new google.maps.InfoWindowOptions({ maxWidth: 400});

        var infowindow = new google.maps.InfoWindow({
            content: contentString,
            maxWidth: 650
        });

        google.maps.event.addListener(marker, 'click', function () {

            closeInfos();

            infowindow.open(map, marker);

            infos[0] = infowindow;
        });
    }
    catch (er) {
        window.location = cERROR_PG
    }
}

// ==============================================================
// ==============================================================

function closeInfos() {

    if (infos.length > 0) {
        infos[0].set("marker", null);
        infos[0].close();
        infos.length = 0;
    }
}

// ==============================================================
// ==============================================================

function FindMarker(markerIndex) {

    try {
        google.maps.event.trigger(markers[markerIndex], 'click');
        map.setCenter(markers[markerIndex].getPosition());
        map.setZoom(13);
    }
    catch (er) {
        window.location = cERROR_PG
    }

}

// ==============================================================
// ==============================================================

function ResetMap() {

    try {
        map.setCenter(latlngSTARTPNT);
        map.setZoom(3);

        grdOrgList.getFilterElement(cTITLE).value = "";
        grdOrgList.getFilterElement(cCITY).value = "";
        grdOrgList.getFilterElement(cPROVFULL).value = "";

        FilterGridForVisibleMarkers();
    }
    catch (er) {
        window.location = cERROR_PG
    }

}

// ==============================================================
// ==============================================================

function UpdateRecCount() {

    try {

        if (filteredLocationData.length == 1) {

            if (userCulture == cCULTURE_FR) {
                document.getElementById('recCount').innerHTML = "Affichage de <b>" + filteredLocationData.length + "</b> organisme agrée";
            } else {
                document.getElementById('recCount').innerHTML = "Displaying <b>" + filteredLocationData.length + "</b> accredited organization";
            }

        } else {

            if (userCulture == cCULTURE_FR) {
                document.getElementById('recCount').innerHTML = "Affichage de <b>" + filteredLocationData.length + "</b> organismes agrées";
            } else {
                document.getElementById('recCount').innerHTML = "Displaying <b>" + filteredLocationData.length + "</b> accredited organizations";
            }

        }
    }
    catch (er) {
        window.location = cERROR_PG
    }

}

// ==============================================================
// ==============================================================

function AddNewButton(controlDiv, map) {

    try {

        // Set CSS styles for the DIV containing the control
        // Setting padding to 5 px will offset the control
        // from the edge of the map
        controlDiv.style.padding = '5px';

        // Set CSS for the control border
        var controlUI = document.createElement('DIV');
        controlUI.style.backgroundImage = getImgSrc(imgNewSearch);
        controlUI.style.borderStyle = 'solid';
        controlUI.style.borderWidth = '1px';
        controlUI.style.cursor = 'pointer';
        if (userCulture == cCULTURE_FR) {
            controlUI.style.width = '124px';
        } else {
            controlUI.style.width = '86px';
        }
        controlUI.style.height = '20px';
        controlDiv.appendChild(controlUI);

        google.maps.event.addDomListener(controlUI, 'click', function () {
            ResetMap();
        });
    }
    catch (er) {
        window.location = cERROR_PG
    }

}

// ==============================================================
// ==============================================================

function getLabel(label) {

    var labelText;

    if (userCulture == cCULTURE_FR) {
        labelText = label[cFR_CA];
    } else {
        labelText = label[cEN_CA];
    }
    return labelText
}

// ==============================================================
// ==============================================================

function getImgSrc(img) {

    var ImgSrc;

    if (userCulture == cCULTURE_FR) {
        ImgSrc = img[cFR_CA];
    } else {
        ImgSrc = img[cEN_CA];
    }
    return "url(" + ImgSrc + ")";
}

// ==============================================================
// ==============================================================

function getHelpSrc(doc) {

    var src;

    if (userCulture == cCULTURE_FR) {
        src = doc[cFR_CA];
    } else {
        src = doc[cEN_CA];
    }
    return src;
}

// ==============================================================
// ==============================================================

function getResultsLabel(label) {

    var title;

    if (userCulture == cCULTURE_FR) {
        title = label[cFR_CA];
    } else {
        title = label[cEN_CA];
    }
    return title;
}

// ==============================================================
// ==============================================================

function InitializeHelpWindows() {

    try {

        var dhxWins = new dhtmlXWindows();
        var win = dhxWins.createWindow("winHelp", 70, 40, 860, 500);
        dhxWins.window("winHelp").setText("AccrediMap Help");
        //dhxWins.setSkin("dhx_web");
        dhxWins.window("winHelp").attachURL(getHelpSrc(helpDocSrc));
    }
    catch (er) {
        window.location = cERROR_PG
    }
}